pg.ddx.io  pgsql-hackers@postgresql.org mailing list archive  
help / color / mirror / Atom feed
From: Nathan Bossart <nathandbossart@gmail.com>
To: Kyotaro Horiguchi <horikyota.ntt@gmail.com>
Cc: pgsql-hackers@postgresql.org
Subject: Re: remove more archiving overhead
Date: Thu, 24 Feb 2022 13:48:53 -0800
Message-ID: <20220224214853.GA661650@nathanxps13> (raw)
In-Reply-To: <20220224175553.GA660690@nathanxps13>
References: <20220222011948.GA3850532@nathanxps13>
	<20220222173711.GA3852671@nathanxps13>
	<20220222195229.GA42988@nathanxps13>
	<20220224.141349.1809640551882183816.horikyota.ntt@gmail.com>
	<20220224175553.GA660690@nathanxps13>

I tested this again with many more WAL files and a much larger machine
(r5d.24xlarge with data directory on an NVMe SSD instance store volume).
As before, I am using a bare-bones archive module that does nothing but
return true.  Without the patch, archiving ~120k WAL files took about 109
seconds.  With the patch, it took around 62 seconds, which amounts to a
~43% reduction in overhead.

-- 
Nathan Bossart
Amazon Web Services: https://aws.amazon.com





view thread (40+ messages)  latest in thread

Message-ID: <20220224214853.GA661650@nathanxps13>
Permalink:  ../20220224214853.GA661650@nathanxps13/
Also on:    postgresql.org/message-id/20220224214853.GA661650@nathanxps13

 · 

reply

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Reply to all the recipients using the --to and --cc options:
  reply via email

  To: pgsql-hackers@postgresql.org
  Cc: nathandbossart@gmail.com, horikyota.ntt@gmail.com
  Subject: Re: remove more archiving overhead
  In-Reply-To: <20220224214853.GA661650@nathanxps13>

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

This inbox is served by DDX for PostgreSQL; see mirroring instructions
for how to clone and mirror all data and code used for this inbox